StaticType

Trait StaticType 

pub unsafe trait StaticType {
    type Static: 'static + ?Sized;

    // Provided method
    fn type_id(&self) -> TypeId { ... }
}

Required Associated Types

type Static: 'static + ?Sized

Provided Methods

fn type_id(&self) -> TypeId

Implementations on Foreign Types

Source

impl StaticType for bool

Source

impl StaticType for char

Source

impl StaticType for f32

Source

impl StaticType for f64

Source

impl StaticType for i8

Source

impl StaticType for i16

Source

impl StaticType for i32

Source

impl StaticType for i64

Source

impl StaticType for i128

Source

impl StaticType for isize

Source

impl StaticType for u8

Source

impl StaticType for u16

Source

impl StaticType for u32

Source

impl StaticType for u64

Source

impl StaticType for u128

Source

impl StaticType for ()

Source

impl StaticType for usize

Source

impl StaticType for String

Source

impl StaticType for PhantomPinned

Source

impl StaticType for AtomicBool

Source

impl StaticType for AtomicI8

Source

impl StaticType for AtomicI16

Source

impl StaticType for AtomicI32

Source

impl StaticType for AtomicI64

Source

impl StaticType for AtomicIsize

Source

impl StaticType for AtomicU8

Source

impl StaticType for AtomicU16

Source

impl StaticType for AtomicU32

Source

impl StaticType for AtomicU64

Source

impl StaticType for AtomicUsize

Source

impl StaticType for Duration

Source

impl StaticType for Once

Source

impl StaticType for BVec2

Source

impl StaticType for BVec3

Source

impl StaticType for BVec4

Source

impl StaticType for Affine2

Source

impl StaticType for Affine3A

Source

impl StaticType for Mat3

Source

impl StaticType for Mat2

Source

impl StaticType for Mat3A

Source

impl StaticType for Mat4

Source

impl StaticType for Quat

Source

impl StaticType for Vec3A

Source

impl StaticType for Vec4

Source

impl StaticType for Vec2

Source

impl StaticType for Vec3

Source

impl StaticType for DAffine2

Source

impl StaticType for DAffine3

Source

impl StaticType for DMat2

Source

impl StaticType for DMat3

Source

impl StaticType for DMat4

Source

impl StaticType for DQuat

Source

impl StaticType for DVec2

Source

impl StaticType for DVec3

Source

impl StaticType for DVec4

Source

impl StaticType for IVec2

Source

impl StaticType for IVec3

Source

impl StaticType for IVec4

Source

impl StaticType for UVec2

Source

impl StaticType for UVec3

Source

impl StaticType for UVec4

Source

impl<'a> StaticType for &'a str

Source

type Static = &'static str

Source

impl<'a, T: 'a + StaticType + ?Sized> StaticType for &'a T

Source

type Static = &'static <T as StaticType>::Static

Source

impl<'a, T: StaticTypeClone + Clone> StaticType for Cow<'a, T>

Available on crate feature alloc only.
Source

type Static = Cow<'static, <T as StaticTypeClone>::Static>

Source

impl<'a, T: StaticTypeSized> StaticType for &'a [T]

Source

type Static = &'static [<T as StaticTypeSized>::Static]

Source

impl<'a, T: StaticTypeSized> StaticType for Box<dyn Iterator<Item = T> + Send + Sync + 'a>

Available on crate feature alloc only.
Source

type Static = Box<dyn Iterator<Item = <T as StaticTypeSized>::Static> + Send + Sync>

Source

impl<'a, T: StaticTypeSized> StaticType for Chunks<'a, T>

Source

type Static = Chunks<'static, <T as StaticTypeSized>::Static>

Source

impl<'a, T: StaticTypeSized> StaticType for ChunksMut<'a, T>

Source

impl<'a, T: StaticTypeSized> StaticType for Iter<'a, T>

Source

type Static = Iter<'static, <T as StaticTypeSized>::Static>

Source

impl<'a, T: StaticTypeSized> StaticType for IterMut<'a, T>

Source

type Static = IterMut<'static, <T as StaticTypeSized>::Static>

Source

impl<'a, T: StaticTypeSized> StaticType for RChunks<'a, T>

Source

type Static = RChunks<'static, <T as StaticTypeSized>::Static>

Source

impl<'a, T: StaticTypeSized> StaticType for RChunksMut<'a, T>

Source

impl<'a, T: StaticTypeSized> StaticType for Windows<'a, T>

Source

type Static = Windows<'static, <T as StaticTypeSized>::Static>

Source

impl<A: StaticTypeSized, B: StaticTypeSized, C: StaticTypeSized, D: StaticTypeSized, E: StaticTypeSized, F: StaticTypeSized, G: StaticTypeSized, H: StaticTypeSized, I: StaticTypeSized, J: StaticTypeSized, K: StaticTypeSized, L: StaticTypeSized> StaticType for (A, B, C, D, E, F, G, H, I, J, K, L)

Source

impl<B: StaticTypeSized, C: StaticTypeSized, D: StaticTypeSized, E: StaticTypeSized, F: StaticTypeSized, G: StaticTypeSized, H: StaticTypeSized, I: StaticTypeSized, J: StaticTypeSized, K: StaticTypeSized, L: StaticTypeSized> StaticType for (B, C, D, E, F, G, H, I, J, K, L)

Source

impl<C: StaticTypeSized, D: StaticTypeSized, E: StaticTypeSized, F: StaticTypeSized, G: StaticTypeSized, H: StaticTypeSized, I: StaticTypeSized, J: StaticTypeSized, K: StaticTypeSized, L: StaticTypeSized> StaticType for (C, D, E, F, G, H, I, J, K, L)

Source

impl<D: StaticTypeSized, E: StaticTypeSized, F: StaticTypeSized, G: StaticTypeSized, H: StaticTypeSized, I: StaticTypeSized, J: StaticTypeSized, K: StaticTypeSized, L: StaticTypeSized> StaticType for (D, E, F, G, H, I, J, K, L)

Source

impl<E: StaticTypeSized, F: StaticTypeSized, G: StaticTypeSized, H: StaticTypeSized, I: StaticTypeSized, J: StaticTypeSized, K: StaticTypeSized, L: StaticTypeSized> StaticType for (E, F, G, H, I, J, K, L)

Source

impl<F: StaticTypeSized, G: StaticTypeSized, H: StaticTypeSized, I: StaticTypeSized, J: StaticTypeSized, K: StaticTypeSized, L: StaticTypeSized> StaticType for (F, G, H, I, J, K, L)

Source

impl<G: StaticTypeSized, H: StaticTypeSized, I: StaticTypeSized, J: StaticTypeSized, K: StaticTypeSized, L: StaticTypeSized> StaticType for (G, H, I, J, K, L)

Source

impl<H: StaticTypeSized, I: StaticTypeSized, J: StaticTypeSized, K: StaticTypeSized, L: StaticTypeSized> StaticType for (H, I, J, K, L)

Source

impl<I: StaticTypeSized, J: StaticTypeSized, K: StaticTypeSized, L: StaticTypeSized> StaticType for (I, J, K, L)

Source

impl<J: StaticTypeSized, K: StaticTypeSized, L: StaticTypeSized> StaticType for (J, K, L)

Source

impl<K: StaticTypeSized, L: StaticTypeSized> StaticType for (K, L)

Source

impl<K: StaticTypeSized, V: StaticTypeSized> StaticType for BTreeMap<K, V>

Source

impl<L: StaticTypeSized> StaticType for (L,)

Source

impl<T: StaticType + ?Sized> StaticType for Box<T>

Available on crate feature alloc only.
Source

impl<T: StaticTypeSized> StaticType for Option<T>

Source

impl<T: StaticTypeSized> StaticType for *const [T]

Source

impl<T: StaticTypeSized> StaticType for *mut [T]

Source

impl<T: StaticTypeSized> StaticType for BinaryHeap<T>

Source

impl<T: StaticTypeSized> StaticType for LinkedList<T>

Source

impl<T: StaticTypeSized> StaticType for VecDeque<T>

Source

impl<T: StaticTypeSized> StaticType for Rc<T>

Source

impl<T: StaticTypeSized> StaticType for Arc<T>

Source

impl<T: StaticTypeSized> StaticType for Vec<T>

Source

impl<T: StaticTypeSized> StaticType for Cell<T>

Source

impl<T: StaticTypeSized> StaticType for RefCell<T>

Source

impl<T: StaticTypeSized> StaticType for UnsafeCell<T>

Source

impl<T: StaticTypeSized> StaticType for Empty<T>

Source

impl<T: StaticTypeSized> StaticType for PhantomData<T>

Source

impl<T: StaticTypeSized> StaticType for ManuallyDrop<T>

Source

impl<T: StaticTypeSized> StaticType for Wrapping<T>

Source

impl<T: StaticTypeSized> StaticType for Range<T>

Source

impl<T: StaticTypeSized> StaticType for AtomicPtr<T>

Source

impl<T: StaticTypeSized> StaticType for Mutex<T>

Source

impl<T: StaticTypeSized> StaticType for RwLock<T>

Source

impl<T: StaticTypeSized> StaticType for MaybeUninit<T>

Source

impl<T: StaticTypeSized, E: StaticTypeSized> StaticType for Result<T, E>

Source

impl<T: StaticTypeSized, const N: usize> StaticType for [T; N]

Source

impl<V: StaticTypeSized> StaticType for BTreeSet<V>

Implementors

Source

impl<'a> StaticType for dyn DynAny<'a> + '_

Source

type Static = dyn DynAny<'static>