Trait dyn_any::StaticType

source ·
pub trait StaticType {
    type Static: 'static + ?Sized;

    // Provided method
    fn type_id(&self) -> TypeId { ... }
}

Required Associated Types

source

type Static: 'static + ?Sized

Provided Methods

source

fn type_id(&self) -> TypeId

Implementations on Foreign Types

source

impl<'a, T: StaticTypeClone + Clone> StaticType for Cow<'a, T>



type Static = Cow<'static, <T as StaticTypeClone>::Static>

source

impl<T: StaticTypeSized> StaticType for *const [T]

source

impl<T: StaticTypeSized> StaticType for *mut [T]

source

impl<'a, T: StaticTypeSized> StaticType for &'a [T]



type Static = &'static [<T as StaticTypeSized>::Static]

source

impl<'a> StaticType for &'a str



type Static = &'static str

source

impl StaticType for ()



type Static = ()

source

impl<'a, T: 'a + StaticType + ?Sized> StaticType for &'a T



type Static = &'static <T as StaticType>::Static

source

impl<T: StaticTypeSized, const N: usize> StaticType for [T; N]



type Static = [<T as StaticTypeSized>::Static; N]

source

impl<T: StaticTypeSized> StaticType for Option<T>

source

impl<T: StaticTypeSized, E: StaticTypeSized> StaticType for Result<T, E>

source

impl<T: StaticTypeSized> StaticType for Cell<T>

source

impl<T: StaticTypeSized> StaticType for UnsafeCell<T>

source

impl<T: StaticTypeSized> StaticType for RefCell<T>

source

impl<T: StaticTypeSized> StaticType for MaybeUninit<T>

source

impl<T: StaticTypeSized> StaticType for ManuallyDrop<T>

source

impl<T: StaticTypeSized> StaticType for PhantomData<T>

source

impl StaticType for PhantomPinned

source

impl<T: StaticTypeSized> StaticType for Empty<T>

source

impl<T: StaticTypeSized> StaticType for Wrapping<T>

source

impl StaticType for Duration

source

impl StaticType for bool



type Static = bool

source

impl StaticType for f32



type Static = f32

source

impl StaticType for f64



type Static = f64

source

impl StaticType for char



type Static = char

source

impl StaticType for u8



type Static = u8

source

impl StaticType for AtomicU8

source

impl StaticType for u16



type Static = u16

source

impl StaticType for AtomicU16

source

impl StaticType for u32



type Static = u32

source

impl StaticType for AtomicU32

source

impl StaticType for u64



type Static = u64

source

impl StaticType for usize

source

impl StaticType for AtomicUsize

source

impl StaticType for i8



type Static = i8

source

impl StaticType for AtomicI8

source

impl StaticType for i16



type Static = i16

source

impl StaticType for AtomicI16

source

impl StaticType for i32



type Static = i32

source

impl StaticType for AtomicI32

source

impl StaticType for i64



type Static = i64

source

impl StaticType for isize

source

impl StaticType for AtomicIsize

source

impl StaticType for i128



type Static = i128

source

impl StaticType for u128



type Static = u128

source

impl StaticType for AtomicBool

source

impl<T: StaticTypeSized> StaticType for AtomicPtr<T>

source

impl StaticType for AtomicU64

source

impl StaticType for AtomicI64

source

impl<T: StaticTypeSized> StaticType for Vec<T>

source

impl StaticType for String

source

impl<K: StaticTypeSized, V: StaticTypeSized> StaticType for BTreeMap<K, V>

source

impl<V: StaticTypeSized> StaticType for BTreeSet<V>

source

impl<T: StaticTypeSized> StaticType for LinkedList<T>

source

impl<T: StaticTypeSized> StaticType for VecDeque<T>

source

impl<T: StaticTypeSized> StaticType for BinaryHeap<T>

source

impl StaticType for Once



type Static = Once

source

impl<T: StaticTypeSized> StaticType for Mutex<T>

source

impl<T: StaticTypeSized> StaticType for RwLock<T>

source

impl<T: StaticTypeSized> StaticType for Rc<T>

source

impl<T: StaticTypeSized> StaticType for Arc<T>

source

impl StaticType for IVec2

source

impl StaticType for IVec3

source

impl StaticType for IVec4

source

impl StaticType for UVec2

source

impl StaticType for UVec3

source

impl StaticType for UVec4

source

impl StaticType for BVec2

source

impl StaticType for BVec3

source

impl StaticType for BVec4

source

impl StaticType for Vec2



type Static = Vec2

source

impl StaticType for Vec3



type Static = Vec3

source

impl StaticType for Vec3A

source

impl StaticType for Vec4



type Static = Vec4

source

impl StaticType for DVec2

source

impl StaticType for DVec3

source

impl StaticType for DVec4

source

impl StaticType for Mat2



type Static = Mat2

source

impl StaticType for Mat3



type Static = Mat3

source

impl StaticType for Mat3A

source

impl StaticType for Mat4



type Static = Mat4

source

impl StaticType for DMat2

source

impl StaticType for DMat3

source

impl StaticType for DMat4

source

impl StaticType for Quat



type Static = Quat

source

impl StaticType for Affine2

source

impl StaticType for Affine3A

source

impl StaticType for DAffine2

source

impl StaticType for DAffine3

source

impl StaticType for DQuat

source

impl<T: StaticType + ?Sized> StaticType for Box<T>

source

impl<A: StaticTypeSized, B: StaticTypeSized, C: StaticTypeSized, D: StaticTypeSized, E: StaticTypeSized, F: StaticTypeSized, G: StaticTypeSized, H: StaticTypeSized, I: StaticTypeSized, J: StaticTypeSized, K: StaticTypeSized, L: StaticTypeSized> StaticType for (A, B, C, D, E, F, G, H, I, J, K, L)

source

impl<B: StaticTypeSized, C: StaticTypeSized, D: StaticTypeSized, E: StaticTypeSized, F: StaticTypeSized, G: StaticTypeSized, H: StaticTypeSized, I: StaticTypeSized, J: StaticTypeSized, K: StaticTypeSized, L: StaticTypeSized> StaticType for (B, C, D, E, F, G, H, I, J, K, L)

source

impl<C: StaticTypeSized, D: StaticTypeSized, E: StaticTypeSized, F: StaticTypeSized, G: StaticTypeSized, H: StaticTypeSized, I: StaticTypeSized, J: StaticTypeSized, K: StaticTypeSized, L: StaticTypeSized> StaticType for (C, D, E, F, G, H, I, J, K, L)

source

impl<D: StaticTypeSized, E: StaticTypeSized, F: StaticTypeSized, G: StaticTypeSized, H: StaticTypeSized, I: StaticTypeSized, J: StaticTypeSized, K: StaticTypeSized, L: StaticTypeSized> StaticType for (D, E, F, G, H, I, J, K, L)

source

impl<E: StaticTypeSized, F: StaticTypeSized, G: StaticTypeSized, H: StaticTypeSized, I: StaticTypeSized, J: StaticTypeSized, K: StaticTypeSized, L: StaticTypeSized> StaticType for (E, F, G, H, I, J, K, L)

source

impl<F: StaticTypeSized, G: StaticTypeSized, H: StaticTypeSized, I: StaticTypeSized, J: StaticTypeSized, K: StaticTypeSized, L: StaticTypeSized> StaticType for (F, G, H, I, J, K, L)

source

impl<G: StaticTypeSized, H: StaticTypeSized, I: StaticTypeSized, J: StaticTypeSized, K: StaticTypeSized, L: StaticTypeSized> StaticType for (G, H, I, J, K, L)

source

impl<H: StaticTypeSized, I: StaticTypeSized, J: StaticTypeSized, K: StaticTypeSized, L: StaticTypeSized> StaticType for (H, I, J, K, L)

source

impl<I: StaticTypeSized, J: StaticTypeSized, K: StaticTypeSized, L: StaticTypeSized> StaticType for (I, J, K, L)

source

impl<J: StaticTypeSized, K: StaticTypeSized, L: StaticTypeSized> StaticType for (J, K, L)

source

impl<K: StaticTypeSized, L: StaticTypeSized> StaticType for (K, L)

source

impl<L: StaticTypeSized> StaticType for (L,)



type Static = (<L as StaticTypeSized>::Static,)

Implementors

source

impl<'a> StaticType for dyn DynAny<'a> + '_



type Static = dyn DynAny<'static> + 'static